import trtwn.fs
import trtwn.matplotlib
import os

def inputStr(path):
    return '\\input{%s}\n' % path

def pythontex(filename, outputDir):
    filename = trtwn.fs.purename(filename)
    filepath = os.path.join(outputDir, filename + ".pgf")

    trtwn.matplotlib.savePgfAndPdf(filepath)

    print(inputStr(filepath))



import numpy as np

def find_nearest(array, value):
    idx = (np.abs(array-value)).argmin()
    return array[idx]

def find_nearest_index(array, value):
    idx = (np.abs(array-value)).argmin()
    return idx



import numpy as np
import scipy.constants as sc

def spp_dispersion_relation_from_w(w, e_1, e_2):
    return w/sc.c * np.sqrt(e_1 * e_2/(e_1 + e_2))

def bulk_plasmon_dispersion_relation_from_w(w, w_p):
    return np.sqrt((w**2-w_p**2)/sc.c**2)

def bulk_plasmon_dispersion_relation_from_k(k, w_p):
    return np.sqrt(w_p**2 + k**2 * sc.c**2)

def nm_to_eV(nm):
    return sc.h*sc.c/(nm * sc.e * sc.nano)

def eV_to_nm(eV):
    return sc.h*sc.c/(eV * sc.e * sc.nano)



import scipy.constants as sc
from trtwn.fs import changeExtension
import matplotlib as mpl
from matplotlib import pylab as plt

def figsize(scale, textwidthInPt, heightRatio=1/sc.golden_ratio): # Get this from LaTeX using \the\textwidth inside \begin{document}\end{document}
    textwidthInInch = textwidthInPt / 72.27 #* sc.pt / sc.inch
    figWidthInInch = textwidthInInch * scale
    figHeightInInch = figWidthInInch * heightRatio
    return [figWidthInInch, figHeightInInch]

def newfig(scale, textwidthInPt, heightRatio=1/sc.golden_ratio):
    size = figsize(scale, textwidthInPt, heightRatio)
    return plt.figure(figsize=size)

def savePgfAndPdf(filepath):
    pgf = changeExtension(filepath, "pgf")
    pdf = changeExtension(filepath, "pdf")
    plt.savefig(pgf, dpi=300)
    plt.savefig(pdf, dpi=300)

def arrowed_spines(fig, ax):

    xmin, xmax = ax.get_xlim()
    ymin, ymax = ax.get_ylim()

    # removing the default axis on all sides:
    for side in ['bottom','right','top','left']:
        ax.spines[side].set_visible(False)

    # removing the axis ticks
    plt.xticks([]) # labels
    plt.yticks([])
    ax.xaxis.set_ticks_position('none') # tick markers
    ax.yaxis.set_ticks_position('none')

    # get width and height of axes object to compute
    # matching arrowhead length and width
    dps = fig.dpi_scale_trans.inverted()
    bbox = ax.get_window_extent().transformed(dps)
    width, height = bbox.width, bbox.height

    # manual arrowhead width and length
    hw = 1./20.*(ymax-ymin)
    hl = 1./20.*(xmax-xmin)
    lw = .2 # axis line width
    ohg = 0.3 # arrow overhang

    # compute matching arrowhead length and width
    yhw = hw/(ymax-ymin)*(xmax-xmin)* height/width
    yhl = hl/(xmax-xmin)*(ymax-ymin)* width/height

    # draw x and y axis
    ax.arrow(xmin, 0, xmax-xmin, 0., fc='k', ec='k', lw = lw,
             head_width=hw, head_length=hl, overhang = ohg,
             length_includes_head= True, clip_on = False)

    ax.arrow(0, ymin, 0., ymax-ymin, fc='k', ec='k', lw = lw,
             head_width=yhw, head_length=yhl, overhang = ohg,
             length_includes_head= True, clip_on = False)



from distutils.core import setup
setup(
  name = 'trtwn',
  packages = ['trtwn'],
  version = '0.2.0',
  description = 'My personal python package with (just for me) useful shorthands',
  author = 'Dennis Trautwein',
  author_email = 'gafwurstula@posteo.net',
  url = 'https://github.com/dennis-tra/trtwn',
  download_url = 'https://github.com/dennis-tra/trtwn/archive/0.1.tar.gz',
  keywords = [],
  install_requires=['matplotlib', 'scipy', 'numpy'],
  classifiers = [],
)



import os

def purename(filename):
    return os.path.splitext(os.path.basename(filename))[0]

def changeExtension(filepath, ext):
    if not ext.startswith("."):
        ext = "." + ext
    return os.path.splitext(filepath)[0] + ext
